@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -419,6 +419,7 @@ struct world_s
   gboolean         autocompletion;
   gint             autocompl_minprefix;
   gchar            command_separator[10];
+  gchar            perl_character;
   gboolean         updating_controls;     /* To prevent infinite loop */
   gboolean         ignore_up_down_keys;
 
@@ -628,7 +629,6 @@ struct prefs_s
   GtkPositionType  tab_position;
   gboolean         hide_single_tab;
   gboolean         urgency_hint;
-  char            *browser_command;
   char            *audio_player_command;
   char            *last_open_world;
   gboolean         no_plugin_help_msg;
@@ -943,6 +943,7 @@ extern gnutls_certificate_credentials_t tls_certif_cred;
 GtkWidget* create_main_window(WorldGUI *gui);
 void       set_main_window_size(int x, int y, int width, int height,
                                 WorldGUI *gui);
+void       add_global_css();
 World*     get_world_to_connect();
 void       remove_world(World *world, gboolean remove_gui);
 gboolean   remove_world_timer(World *world);
