@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -285,6 +285,29 @@ set_initial_window_size(WorldGUI *gui)
 }
 
 
+void
+add_global_css()
+{
+  GtkCssProvider *provider;
+  GdkDisplay     *display;
+  GdkScreen      *screen;
+
+  gchar *css =
+    "menu {"              /* Use system font in popup menus, */
+    " font: initial;"     /* instead of the mud output font. */
+    "}";
+
+  provider = gtk_css_provider_new();
+  gtk_css_provider_load_from_data(provider, css, -1, NULL);
+
+  display = gdk_display_get_default();
+  screen = gdk_display_get_default_screen(display);
+  gtk_style_context_add_provider_for_screen(screen,
+                                            GTK_STYLE_PROVIDER(provider),
+                                            GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+}
+
+
 gboolean
 exit_cb(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
