@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -266,6 +266,7 @@ perl_match(const char      *line,
                      " defined($+[$target]) ? $+[$target] : 0,"
                      " $match);",
                      (substring != -1 ? substring : 0));
+  SvUTF8_on(command);
 
   /* Run the command */
   ENTER;
@@ -329,6 +330,7 @@ perl_substitute(const char      *line,
                      substitution,
                      global    ? "g" : "",
                      perl_eval ? "e" : "");
+  SvUTF8_on(command);
 
   /* Run the command */
   ENTER;
@@ -364,6 +366,7 @@ precompute_re(const char      *re_string,
   command = newSVpvf("$_re = qr\x05%s\x05%s;",
                      re_string,
                      ignore_case ? "i" : "");
+  SvUTF8_on(command);
   ENTER;
   SAVETMPS;
   PUSHMARK(SP);
@@ -896,6 +899,7 @@ XS_getname(pTHX_ CV *perlcv)
 
   /* And now return the current value */
   XST_mPV(0, world->name);
+  SvUTF8_on(ST(0));
   XSRETURN(1);
 }
 
@@ -929,6 +933,7 @@ XS_getcharacter(pTHX_ CV *perlcv)
                      LOGON_CHAR, &character,
                      -1);
   XST_mPV(0, character);
+  SvUTF8_on(ST(0));
   g_free(character);
   gtk_tree_path_free(path);
 
@@ -947,6 +952,7 @@ XS_getmainfont(pTHX_ CV *perlcv)
 
   /* And now return the current value */
   XST_mPV(0, world->terminalfont);
+  SvUTF8_on(ST(0));
   XSRETURN(1);
 }
 
@@ -962,6 +968,7 @@ XS_getentryfont(pTHX_ CV *perlcv)
 
   /* And now return the current value */
   XST_mPV(0, world->entryfont);
+  SvUTF8_on(ST(0));
   XSRETURN(1);
 }
 
@@ -1003,6 +1010,7 @@ XS_cmdseparator(pTHX_ CV *perlcv)
 
   /* And now return the current value */
   XST_mPV(0, world->command_separator);
+  SvUTF8_on(ST(0));
   XSRETURN(1);
 }
 
@@ -1236,6 +1244,7 @@ XS_getinput(pTHX_ CV *perlcv)
   text = simo_combo_box_get_text(world->gui->cmbEntry);
 
   XST_mPV(0, text);
+  SvUTF8_on(ST(0));
   XSRETURN(1);
 }
 
@@ -1306,7 +1315,8 @@ XS_getline(pTHX_ CV *perlcv)
                                   FALSE);
 
   XST_mPV(0, text);
-    g_free(text);
+  SvUTF8_on(ST(0));
+  g_free(text);
   if (GIMME_V == G_ARRAY) {
     XST_mIV(1, k_circular_queue_nth(world->gui->line_times,
                                     time_t,
@@ -1404,6 +1414,7 @@ XS_stripansi(pTHX_ CV *perlcv)
   stripped = strip_ansi(original, len);
 
   XST_mPV(0, stripped);
+  SvUTF8_on(ST(0));
   g_free(stripped);
   XSRETURN(1);
 }
@@ -2190,11 +2201,12 @@ XS_expandalias(pTHX_ CV *perlcv)
 
   line = SvPV_nolen(ST(1));
   tmp = get_sv("_tmpexpalias", TRUE);
+  SvUTF8_on(tmp);
   sv_setpv(tmp, line);
 
   aliasptr = world->aliases;
   while (aliasptr) {
-    gchar *subcmd;
+    SV *subcmd;
 
     alias = (Alias *) aliasptr->data;
 
@@ -2205,18 +2217,20 @@ XS_expandalias(pTHX_ CV *perlcv)
     /* Set the regexp in a variable */
     re = get_sv("_re", TRUE);
     sv_setsv(re, alias->pattern_re);
-    subcmd = g_strdup_printf("$_tmpexpalias =~ s\x05$_re\x05%s\x05%s;",
-                             alias->substitution,
-                             alias->perl_eval ? "e" : "");
-    eval_pv(subcmd, TRUE);
-    g_free(subcmd);
+
+    subcmd = newSVpvf("$_tmpexpalias =~ s\x05$_re\x05%s\x05%s;",
+                      alias->substitution,
+                      alias->perl_eval ? "e" : "");
+    SvUTF8_on(subcmd);
+    eval_sv(subcmd, G_VOID);
+    SvREFCNT_dec(subcmd);
 
     aliasptr = aliasptr->next;
   }
 
   resultline = SvPV_nolen(tmp);
   XST_mPV(0, resultline);
-
+  SvUTF8_on(ST(0));
   XSRETURN(1);
 }
 
@@ -2332,6 +2346,7 @@ XS_getkeycode(pTHX_ CV *perlcv)
   gtk_main();
   /* After gtk_main_quit() is called in the event handler... */
   XST_mPV(0, world->keycode_to_print);
+  SvUTF8_on(ST(0));
   g_free(world->keycode_to_print);
 
   XSRETURN(1);
@@ -3314,6 +3329,7 @@ XS_getlogfile(pTHX_ CV *perlcv)
 
   if (world->log_file) {
     XST_mPV(0, world->log_actual_file);
+    SvUTF8_on(ST(0));
     XSRETURN(1);
   } else {
     XSRETURN_UNDEF;
@@ -3526,6 +3542,7 @@ XS_getpluginversion(pTHX_ CV *perlcv)
   } else {
     XST_mPV(0, plugin->version);
   }
+  SvUTF8_on(ST(0));
 
   XSRETURN(1);
 }
