@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -92,7 +92,6 @@ show_preferences_dialog_cb(GtkMenuItem *widget, gpointer data)
   GObject          *txtProxyUser;
   GObject          *txtProxyPassword;
 #ifndef __MINGW32__
-  GObject          *txtBrowserCommand;
   GObject          *txtAudioPlayerCommand;
 #else
   GtkWidget        *tabPrograms;
@@ -179,12 +178,6 @@ show_preferences_dialog_cb(GtkMenuItem *widget, gpointer data)
 
 #ifndef __MINGW32__
     /* Load commands */
-    txtBrowserCommand = gtk_builder_get_object(main_builder, "txtBrowserCommand");
-    gtk_entry_set_text(GTK_ENTRY(txtBrowserCommand),
-                       globalPrefs.browser_command);
-    g_signal_connect(txtBrowserCommand, "focus_out_event",
-                     G_CALLBACK(txt_cmd_focus_out_cb),
-                     &globalPrefs.browser_command);
     txtAudioPlayerCommand
       = gtk_builder_get_object(main_builder, "txtAudioPlayerCommand");
     gtk_entry_set_text(GTK_ENTRY(txtAudioPlayerCommand),
@@ -320,9 +313,6 @@ read_global_preferences(int *x, int *y, int *width, int *height)
   }
 
   /* Has the commands been set? */
-  if (!globalPrefs.browser_command) {
-    globalPrefs.browser_command = g_strdup("${BROWSER} \"%s\" &");
-  }
   if (!globalPrefs.audio_player_command) {
     globalPrefs.audio_player_command = g_strdup("play \"%s\" &");
   }
@@ -381,8 +371,6 @@ read_global_preferences_from(FILE *fp,
       globalPrefs.hide_single_tab = atoi(line + pos + 1);
     } else if (strcmp(first_word, "urgencyhint") == 0) {
       globalPrefs.urgency_hint = atoi(line + pos + 1);
-    } else if (strcmp(first_word, "browsercommand") == 0) {
-      globalPrefs.browser_command = g_strdup(line + pos + 1);
     } else if (strcmp(first_word, "audioplayercommand") == 0) {
       globalPrefs.audio_player_command = g_strdup(line + pos + 1);
     } else if (strcmp(first_word, "lastopenworld") == 0) {
@@ -468,8 +456,6 @@ get_preferences_string(void)
                          globalPrefs.hide_single_tab);
   g_string_append_printf(str, "urgencyhint %d\n", globalPrefs.urgency_hint);
 
-  g_string_append_printf(str,
-                         "browsercommand %s\n", globalPrefs.browser_command);
   g_string_append_printf(str,
                          "audioplayercommand %s\n",
                          globalPrefs.audio_player_command);
