@@ -168,6 +168,8 @@ static gboolean simo_combo_box_txtview_keypress_cb(GtkWidget   *widget,
                                                    GdkEventKey *evt,
                                                    gpointer     data);
 
+static int      get_screen_height(GtkWidget *widget);
+
 static void     simo_combo_box_popup_close(SimoComboBox *combo_box);
 
 static gchar   *get_gvalue_as_string(GValue *value);
@@ -1415,7 +1417,7 @@ simo_combo_box_popup(SimoComboBox *combo_box)
   by += alloc.y + alloc.height;
 
    // Display above the text box if there isn't space below
-  screen_height = gdk_screen_height();
+  screen_height = get_screen_height(widget);
   if (by + height > screen_height) {
     by -= (alloc.height + height);
   }
@@ -1439,6 +1441,24 @@ simo_combo_box_popup(SimoComboBox *combo_box)
 }
 
 
+static
+int
+get_screen_height(GtkWidget *widget)
+{
+  GdkWindow    *window;
+  GdkDisplay   *display;
+  GdkMonitor   *monitor;
+  GdkRectangle  rectangle;
+
+  window = gtk_widget_get_window(widget);
+  display = gdk_display_get_default();
+  monitor = gdk_display_get_monitor_at_window(display, window);
+
+  gdk_monitor_get_geometry(monitor, &rectangle);
+  return rectangle.height;
+}
+
+
 static
 void
 simo_combo_box_popup_close(SimoComboBox *combo_box)
