@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -256,6 +256,7 @@ fill_we_advanced_tab(World *world, GtkBuilder *ui_builder)
   GtkToggleButton *chkShowPlugin;
   GtkToggleButton *chkKeepAlive;
   GtkToggleButton *chkIgnoreUpDown;
+  GtkEntryBuffer  *txtPerlCharacter;
 
   if (!world) {
     return;
@@ -271,6 +272,9 @@ fill_we_advanced_tab(World *world, GtkBuilder *ui_builder)
     = GTK_TOGGLE_BUTTON(gtk_builder_get_object(ui_builder, "chkKeepAlive"));
   chkIgnoreUpDown
     = GTK_TOGGLE_BUTTON(gtk_builder_get_object(ui_builder, "chkIgnoreUpDown"));
+  txtPerlCharacter
+    = gtk_entry_get_buffer(GTK_ENTRY(gtk_builder_get_object(ui_builder,
+                                                            "txtPerlChar")));
 
   if (world != default_world) {
     txtWorldFile = GTK_ENTRY(gtk_builder_get_object(ui_builder, "txtWorldFile"));
@@ -303,6 +307,8 @@ fill_we_advanced_tab(World *world, GtkBuilder *ui_builder)
   gtk_toggle_button_set_active(chkShowPlugin,    world->show_plugin_items);
   gtk_toggle_button_set_active(chkKeepAlive,     world->keep_alive);
   gtk_toggle_button_set_active(chkIgnoreUpDown,  world->ignore_up_down_keys);
+
+  gtk_entry_buffer_set_text(txtPerlCharacter, &world->perl_character, 1);
 }
 
 
@@ -318,6 +324,7 @@ update_we_advanced_parameters(World *world, gboolean *newworld,
   gchar           *newcharset;
   GtkTreeIter      iter;
   GtkToggleButton *chkIgnoreUpDown;
+  GtkEntry        *txtPerlCharacter;
 
   cmbCharset      = GTK_COMBO_BOX(gtk_builder_get_object(ui_builder,
                                                          "cmbCharset"));
@@ -325,6 +332,8 @@ update_we_advanced_parameters(World *world, gboolean *newworld,
                                                              "chkKeepAlive"));
   chkIgnoreUpDown = GTK_TOGGLE_BUTTON(gtk_builder_get_object(ui_builder,
                                                              "chkIgnoreUpDown"));
+  txtPerlCharacter
+    = GTK_ENTRY(gtk_builder_get_object(ui_builder, "txtPerlChar"));
 
   if (world != default_world) {
     txtWorldFile = GTK_ENTRY(gtk_builder_get_object(ui_builder,
@@ -359,6 +368,8 @@ update_we_advanced_parameters(World *world, gboolean *newworld,
   world->keep_alive = gtk_toggle_button_get_active(chkKeepAlive);
 
   world->ignore_up_down_keys = gtk_toggle_button_get_active(chkIgnoreUpDown);
+
+  world->perl_character = gtk_entry_get_text(txtPerlCharacter)[0];
 }
 
 
