@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1021,10 +1021,6 @@ configure_css(WorldGUI *gui, World *world)
     "  %s;"
     "}"
 
-    ".link-popup-menu {" /* Use system font in the popup menu, */
-    "  font: initial;"   /* instead of the mud output font. */
-    "}"
-
     ".mud-output text selection {"
     "  background-color: #94c9ed;"
     "  color: #000000;"
@@ -1139,10 +1135,7 @@ act_if_link(WorldGUI *gui, GtkTextIter *iter,
     gtk_builder_connect_signals(ui_builder, matched_url);
 
     gtk_menu_attach_to_widget(mnuPopupURL, widget, NULL);
-    add_css_provider_and_class(GTK_WIDGET(mnuPopupURL), gui->css_provider,
-                               "link-popup-menu");
-    gtk_menu_popup(mnuPopupURL, NULL, NULL, NULL, NULL,
-                   event->button, event->time);
+    gtk_menu_popup_at_pointer(mnuPopupURL, (GdkEvent *) event);
     g_object_unref(ui_builder);
   }
 
@@ -1154,13 +1147,15 @@ act_if_link(WorldGUI *gui, GtkTextIter *iter,
 void
 menu_url_open(GtkMenuItem *menu, char *url)
 {
-  char *to_run;
+  GError *err = NULL;
 
-  to_run = g_strdup_printf(globalPrefs.browser_command, url);
+  gtk_show_uri_on_window(GTK_WINDOW(wndMain), url, GDK_CURRENT_TIME, &err);
+  if (err != NULL) {
+    fprintf(stderr, "Error opening URL: %s\nCheck if gvfs is installed\n",
+            err->message);
+    g_error_free(err);
+  }
 
-  system(to_run);
-
-  g_free(to_run);
   g_free(url);
 }
 #else /* defined __MINGW32__ */
