@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -74,6 +74,7 @@ typedef enum {
   KC_COMMAND_HISTORY,
   KC_AUTO_COMPLETION,
   KC_COMMAND_SEPARATOR,
+  KC_PERL_CHARACTER,
   KC_INPUT_LINES,
   KC_INPUT_SPELL,
   KC_CONFIRM_DELETE,
@@ -269,6 +270,7 @@ create_new_world(gboolean load_defaults)
   world->autocompletion      = default_world->autocompletion;
   world->autocompl_minprefix = default_world->autocompl_minprefix;
   strcpy(world->command_separator, default_world->command_separator);
+  world->perl_character      = default_world->perl_character;
 
   world->confirm_delete = default_world->confirm_delete;
 
@@ -349,6 +351,7 @@ create_default_world(void)
   default_world->autocompletion      = TRUE;
   default_world->autocompl_minprefix = 3;
   strcpy(default_world->command_separator, "%;");
+  default_world->perl_character      = '/';
 
   default_world->confirm_delete = TRUE;
 
@@ -1137,6 +1140,21 @@ xml_start_element(GMarkupParseContext *context,
         ++attribute_names;
         ++attribute_values;
       }
+    } else if (strcmp(element_name, "perl-character") == 0) {
+      parser->state = KC_PERL_CHARACTER;
+      if (parser->forWorldSelector) {
+        break;
+      }
+
+      while (*attribute_names) {
+        if (strcmp(*attribute_names, "char") == 0) {
+          parser->world->perl_character = *attribute_values[0];
+        } else {
+          xml_error_unknown_attribute(error, *attribute_names, context);
+        }
+        ++attribute_names;
+        ++attribute_values;
+      }
     } else if (strcmp(element_name, "input-lines") == 0) {
       parser->state = KC_INPUT_LINES;
       if (parser->forWorldSelector) {
@@ -1694,6 +1712,7 @@ xml_end_element(GMarkupParseContext *context,
   case KC_COMMAND_HISTORY:
   case KC_AUTO_COMPLETION:
   case KC_COMMAND_SEPARATOR:
+  case KC_PERL_CHARACTER:
   case KC_INPUT_LINES:
   case KC_INPUT_SPELL:
   case KC_CONFIRM_DELETE:
@@ -2113,6 +2132,7 @@ save_world_to_file(World *world)
                              "  <command-history size=\"%d\" ignore-up-down-keys=\"%d\" />\n"
                              "  <auto-completion enabled=\"%d\" minprefix=\"%d\" />\n"
                              "  <command-separator separator=\"%s\" />\n"
+                             "  <perl-character char=\"%c\" />\n"
                              "  <input-lines size=\"%d\" save=\"%d\" />\n",
                              world->repeat_commands,
                              world->cmd_echo,
@@ -2123,6 +2143,7 @@ save_world_to_file(World *world)
                              world->autocompletion,
                              world->autocompl_minprefix,
                              world->command_separator,
+                             world->perl_character,
                              world->input_n_lines,
                              world->input_n_lines_saved);
   g_string_append_printf(file_contents,
